====================
Kenzo Kit for Django
====================

Базовые модели и вьюшки для нормального REST API

Quick start
-----------

Add "kk" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'kk',
    ]
